use strict;
use warnings;
use Test::More;

eval "use Test::Spelling";
plan skip_all => "Test::Spelling required for testing POD spelling" if $@;

my @ignore = (<<EOI =~ /^\s*(.*)\s*$/mg);
 Wi
 Fi
 tchotchkes
 github
 publically
 financials
 Zentyal
 YAPCs
 Yaco
 ECTS
 Letras
 Aula
 FSO
 Facultad
 Magna
 TPF
 YEF
 SMEs
 ALSA
 estacion
 Seville
 Sur
 CEDI
 Malaga
 CPAN
 EduRoam
 Facebook
 GitHub
 MJD
 UGR
 don
 hackaton
 Málaga
 AMS
 Abba
 Albergue
 Avda
 ALSA
 BHX
 Blulabs
 Bockenheim
 CDG
 CEC
 CIG
 CPH
 Codeko
 Constitución
 ECAL
 ETSIIT
 EvoStar
 FOSDEM
 FRA
 GeNeura
 Generalife
 Granadas
 Inteligence
 JJ
 LIS
 Lisbon
 Munich
 Libre
 MUC
 Macia
 Mallorca
 Merelo
 Mora
 Málaga
 NotBarraLibreCamp
 OSL
 PDF
 PHP
 PPSN
 Palacio
 Pensiones
 Puerta
 RIX
 Saalbau
 Severo
 Telekom
 Titusbau
 Vincci
 Vía
 WLAN
 Westend
 WiFi
 YAPC
 brian
 consortiums
 coworking
 de
 devroom
 devrooms
 grafitti
 grafittis
 hackathon
 hackathons
 identi
 las
 multi
 pdf
 pre
 scalable
 tapa
 tchochkes
 tubo
 Albayzin
 Alpujarras
 kms
 ElasticSearch
 JENUI
 HDMI
 Kuperman
 USB
 Muntada
 Parque
 Ciencias
 laga
 th
 Albayzin
 Fandi\xf1o
 BOFs
 Oficina
 avanzado
 informatics
 FullHD
 ness
 PAX
 Toilettes
 Capside
 Qindel
 Garcia
 AC
 AFAIK
 Alex
 Barcelona.pm
 CS
 Castillo
 Codeko.com
 Damian
 EC
 Ethernet
 Europe
 Frankfurt
 Gran
 Granada.pm
 Juan
 London
 Madrid.pm
 Maribel
 Ochoa
 PhD
 Salvador
 Sightseeing
 Sofia
 Software
 Spain
 Website
 allotted
 app
 attendee
 attendees
 audiovisual
 ballpark
 buses
 cafes
 centre
 countdown
 database
 dept
 email
 equipped
 etc
 glitch
 graffiti
 held
 identi.ca
 incurred
 near
 perl5i
 postdoc
 programming
 spreadsheet
 supra
 toolkit
 vegan
 wheelchairs
 CoSECiVi
 IWANN
 IPs
 CIG2012
 JENUI2008
 software
 NAQ
 MH
 LastMinute
EOI

local $ENV{LC_ALL} = 'C';
add_stopwords(@ignore);
all_pod_files_spelling_ok();

